/*
--------------------------------------------------------------------
                                                             
    NDELTATIME.C                                               
                                                             
    Function to compute an instant of time after or before
       a given reference instant, passed as parameter. The 
       difference is also given as a parameter. 
    
    Call:

       ndeltatime( yyyymmddhh , hh )  
       
    where:  yyyymmddhh - reference instant of time
            hh         - delta (difference, in hours) 

    returns  int (format = yyyymmddhh)
 
    EFOF, 31/03/95 Adapted from deltahour.c (callable from shell
                                               command line)
    EFOF, 22/12/1998 Com o nome de ndeltatime.c 
                                           (ano c/ 4 digitos)
                                                            
------------------------------------------------------------------ 
*/
#include <stdio.h>

int daysofmonth(int year, int month)
{
   int days;
   static int daytab[12] = {
        31,28,31,30,31,30,31,31,30,31,30,31};
   
   days=daytab[month-1];
   if (((year % 4) == 0) && (month == 2))
      days=29;
   return days;
} 
   
int ndeltatime_(int *yyyymmddhh, int *hh)
{
   int reftime, delta, newtime;
   int dr,df,mr,mf,yr,yf,hr,hf,deltaday;
   
 /*  fprintf(stderr,"\n(ndeltatime)yyyymmddhh=%10d\n",*yyyymmddhh);*/

   reftime=*yyyymmddhh;
   delta=*hh;
   hr=(reftime % 100);
   reftime = (reftime - hr) / 100;
   dr=(reftime % 100);
   reftime = (reftime - dr) / 100;
   mr=(reftime % 100);
   reftime = (reftime - mr) / 100;
   yr=reftime;

   deltaday=delta/24;
   delta=delta%24;
   hf=hr+delta;
   if (hf >= 24) {
      hf=hf-24;
      deltaday++;
      }
   else 
      if (hf < 0) {
         hf=hf+24;
         deltaday--;        
      }
   yf=yr;
   mf=mr;
   df=dr+deltaday;
   while (df < 1 || df > daysofmonth(yf,mf)) { 
      /* it's another month */
      if (df < 1) { /* it's previous month  */
        if (mf == 1){
           mf=12;
           yf=yf-1;
        }
        else
           mf=mf-1;
        df=df+daysofmonth(yf,mf);
      }
      else {   /* it's next month */
        df=df-daysofmonth(yf,mf);
        if (mf == 12){
           mf=1;
           yf=yf+1;
        }
        else
           mf=mf+1;
      }  
   }     
   newtime=yf;
   newtime=100*newtime+mf;
   newtime=100*newtime+df;
   newtime=100*newtime+hf;
   return newtime;
}
   
      
    
