/*
        readany.c
*/
#include "bufrgrib.h"
#ifndef NULL
#define NULL 0
#endif

static int file_read(char * buff, int leng, void * file)
/*  
    buff = buffer to fill,
    leng = size of buff in bytes,
    file = FILE *.

    Returns the number of bytes read.
    On EOF, returns negative value for number of bytes read .
*/
{
int nbytes;

    nbytes = (int) fread( buff, 1, leng, (FILE *) file);

/* If EOF, return negative number of bytes read */
    if ( feof((FILE *) file ) )
    {
        clearerr( (FILE *) file );
        return (-nbytes);
    }

    return nbytes;
}

int readany(FILE * file, char * buffer, int * prod_len)
/*

    file          =  file pointer returned from PBOPEN

    buffer        = buffer big enough to hold the product

    prod_len      = size of the buffer on input, becomes size in BYTES of 
                    the product read.  If the end-of-file is hit, the
                    value is returned unchanged (ie. when the function return
                    code is -1).

    Function returns:

        0  if a product has been successfully read

       -1  if end-of-file is hit before a product is read

       -2  if there is an error in the file-handling 
           (eg. if the file contains a truncated product)

       -3  if the size of buffer is not sufficient for the product

*/
{

/* Read the product */
int length;
int original_len;

    original_len = *prod_len;
    length =  readprod( NULL, buffer, &original_len, file_read, file);
    *prod_len = original_len;

    if ( buffer == NULL )
        return ( length == -1 ? length : -3 );
    else
        return ( length > 0 ? 0 : length );

}
